@@ -1,15 +1,15 @@
 # -*- coding: utf-8 -*-
 
-## Copyright 1999-2010 by LivingLogic AG, Bayreuth/Germany
-## Copyright 1999-2010 by Walter Dörwald
+## Copyright 1999-2013 by LivingLogic AG, Bayreuth/Germany
+## Copyright 1999-2013 by Walter Dörwald
 ##
 ## All Rights Reserved
 ##
-## See ll/__init__.py for the license
+## See ll/xist/__init__.py for the license
 
 
 """
-Namespace module for Struts__ configuration files: 
+Namespace module for Struts__ configuration files:
 http://jakarta.apache.org/struts/dtds/struts-config_1_1.dtd.
 
 
@@ -55,11 +55,11 @@ class action(ElementWithID):
 		class path(xsc.TextAttr): required = True
 		class prefix(xsc.TextAttr): pass
 		class roles(xsc.TextAttr): pass
-		class scope(xsc.TextAttr): values = (u"request", u"session")
+		class scope(xsc.TextAttr): values = ("request", "session")
 		class suffix(xsc.TextAttr): pass
 		class type(xsc.TextAttr): pass
-		class unknown(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
-		class validate(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class unknown(xsc.TextAttr): values = ("true", "false", "yes", "no")
+		class validate(xsc.TextAttr): values = ("true", "false", "yes", "no")
 
 
 class action_mappings(ElementWithID):
@@ -75,12 +75,12 @@ class controller(ElementWithID):
 		class contentType(xsc.TextAttr): pass
 		class debug(xsc.TextAttr): pass
 		class forwardPattern(xsc.TextAttr): pass
-		class inputForward(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
-		class locale(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class inputForward(xsc.TextAttr): values = ("true", "false", "yes", "no")
+		class locale(xsc.TextAttr): values = ("true", "false", "yes", "no")
 		class maxFileSize(xsc.TextAttr): pass
 		class memFileSize(xsc.TextAttr): pass
 		class multipartClass(xsc.TextAttr): pass
-		class nocache(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class nocache(xsc.TextAttr): values = ("true", "false", "yes", "no")
 		class pagePattern(xsc.TextAttr): pass
 		class processorClass(xsc.TextAttr): pass
 		class tempDir(xsc.TextAttr): pass
@@ -121,7 +121,7 @@ class form_bean(ElementWithID):
 	xmlname = "form-bean"
 	class Attrs(ElementWithID.Attrs):
 		class className(xsc.TextAttr): pass
-		class dynamic(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class dynamic(xsc.TextAttr): values = ("true", "false", "yes", "no")
 		class name(xsc.TextAttr): required = True
 		class type(xsc.TextAttr): required = True
 
@@ -145,10 +145,10 @@ class form_property(xsc.Element):
 class forward(ElementWithID):
 	class Attrs(ElementWithID.Attrs):
 		class className(xsc.TextAttr): pass
-		class contextRelative(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class contextRelative(xsc.TextAttr): values = ("true", "false", "yes", "no")
 		class name(xsc.TextAttr): required = True
 		class path(xsc.TextAttr): required = True
-		class redirect(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class redirect(xsc.TextAttr): values = ("true", "false", "yes", "no")
 
 
 class global_exceptions(ElementWithID):
@@ -175,7 +175,7 @@ class message_resources(ElementWithID):
 		class className(xsc.TextAttr): pass
 		class factory(xsc.TextAttr): pass
 		class key(xsc.TextAttr): pass
-		class null(xsc.TextAttr): values = (u"true", u"false", u"yes", u"no")
+		class null(xsc.TextAttr): values = ("true", "false", "yes", "no")
 		class parameter(xsc.TextAttr): required = True
 
 
@@ -233,9 +233,9 @@ class user_struts_config(xsc.Element):
 	def convert(self, converter):
 		e = xsc.Frag(
 			xml.XML(),
-			u"\n",
+			"\n",
 			DocType(),
-			u"\n",
+			"\n",
 			struts_config(self.content)
 		)
 		return e.convert(converter)
